@@ -564,13 +564,10 @@ class Client(object):
             expiration,
         )
 
-        cancelSignature = utils.sign_cancel_order(cancelId, self.private_key)
-
         return self._post(
             '/v1/dex/orders/replace',
             data=json.dumps(utils.remove_nones({
                 'cancelId': cancelId,
-                'cancelSignature': cancelSignature,
                 'fillOrKill': fillOrKill,
                 'postOnly': postOnly,
                 'clientId': clientId,
